pub struct VerificationRule {
pub target_contract_id: String,
pub target_provider_id: Option<String>,
pub verifier_provider_id: String,
pub verifier_args: Value,
}Expand description
Route one completed capability call to a verifier provider.
Fields
target_contract_id: Stringtarget_provider_id: Option<String>verifier_provider_id: Stringverifier_args: ValueTrait Implementations
Sourceimpl Clone for VerificationRule
impl Clone for VerificationRule
Sourcefn clone(&self) -> VerificationRule
fn clone(&self) -> VerificationRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationRule
impl Debug for VerificationRule
Sourceimpl<'de> Deserialize<'de> for VerificationRule
impl<'de> Deserialize<'de> for VerificationRule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for VerificationRule
impl PartialEq for VerificationRule
Sourcefn eq(&self, other: &VerificationRule) -> bool
fn eq(&self, other: &VerificationRule) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VerificationRule