run_until_terminal

Function run_until_terminal 

pub async fn run_until_terminal(
    call: &CapabilityCall,
    group: &AsyncGroup,
    self_provider_id: &str,
    atlas: &mut AtlasClient,
    node: &NodeEventContext,
    runtime: &PlanRuntime,
) -> (CapabilityCallResult, u32)
Dispatch an async cap and poll status every 2s. The caller owns the single terminal event so successful work can be verified before it is published.