startup_driver_endpoint

Function startup_driver_endpoint 

pub(crate) fn startup_driver_endpoint(listen_addr: SocketAddr) -> String
Return a loopback endpoint for an unspecified bind address so the process can self-dial without changing the endpoint it advertises through Atlas.