pub struct StartVoiceSessionRequest {
pub session_id: String,
pub client_user_id: String,
pub record_seconds: u32,
pub language: String,
pub tts_enabled: bool,
pub mic_node_id: String,
pub asr_node_id: String,
pub voiceprint_node_id: String,
pub tts_node_id: String,
pub speaker_node_id: String,
pub context_json: String,
}Fields
session_id: Stringclient_user_id: Stringrecord_seconds: u32language: Stringtts_enabled: boolmic_node_id: Stringasr_node_id: Stringvoiceprint_node_id: Stringtts_node_id: Stringspeaker_node_id: Stringcontext_json: StringTrait Implementations
Sourceimpl Clone for StartVoiceSessionRequest
impl Clone for StartVoiceSessionRequest
Sourcefn clone(&self) -> StartVoiceSessionRequest
fn clone(&self) -> StartVoiceSessionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartVoiceSessionRequest
impl Debug for StartVoiceSessionRequest
Sourceimpl Default for StartVoiceSessionRequest
impl Default for StartVoiceSessionRequest
Sourceimpl Hash for StartVoiceSessionRequest
impl Hash for StartVoiceSessionRequest
Sourceimpl Message for StartVoiceSessionRequest
impl Message for StartVoiceSessionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StartVoiceSessionRequest
impl PartialEq for StartVoiceSessionRequest
impl Eq for StartVoiceSessionRequest
impl StructuralPartialEq for StartVoiceSessionRequest