pub struct UpdateObjectLabelRequest {
pub object_id: String,
pub label: String,
pub clear_override: bool,
pub expected_map_id: String,
pub expected_generation: i64,
pub persist_to_snapshot: bool,
pub note: String,
}Fields
object_id: Stringlabel: Stringclear_override: boolexpected_map_id: Stringexpected_generation: i64persist_to_snapshot: boolnote: StringTrait Implementations
Sourceimpl Clone for UpdateObjectLabelRequest
impl Clone for UpdateObjectLabelRequest
Sourcefn clone(&self) -> UpdateObjectLabelRequest
fn clone(&self) -> UpdateObjectLabelRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateObjectLabelRequest
impl Debug for UpdateObjectLabelRequest
Sourceimpl Default for UpdateObjectLabelRequest
impl Default for UpdateObjectLabelRequest
impl Eq for UpdateObjectLabelRequest
Sourceimpl Hash for UpdateObjectLabelRequest
impl Hash for UpdateObjectLabelRequest
Sourceimpl Message for UpdateObjectLabelRequest
impl Message for UpdateObjectLabelRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateObjectLabelRequest
impl PartialEq for UpdateObjectLabelRequest
Sourcefn eq(&self, other: &UpdateObjectLabelRequest) -> bool
fn eq(&self, other: &UpdateObjectLabelRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateObjectLabelRequest