pub struct ComponentStatus {
pub id: String,
pub parent_id: String,
pub kind: u32,
pub name: String,
pub frame_id: String,
pub model: String,
pub serial: String,
pub health: u32,
pub operational_state: u32,
pub present: bool,
pub online: bool,
pub detail: String,
}Fields
id: Stringparent_id: Stringkind: u32name: Stringframe_id: Stringmodel: Stringserial: Stringhealth: u32operational_state: u32present: boolonline: booldetail: StringTrait Implementations
Sourceimpl Clone for ComponentStatus
impl Clone for ComponentStatus
Sourcefn clone(&self) -> ComponentStatus
fn clone(&self) -> ComponentStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentStatus
impl Debug for ComponentStatus
Sourceimpl Default for ComponentStatus
impl Default for ComponentStatus
Sourceimpl Hash for ComponentStatus
impl Hash for ComponentStatus
Sourceimpl Message for ComponentStatus
impl Message for ComponentStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ComponentStatus
impl PartialEq for ComponentStatus
Sourcefn eq(&self, other: &ComponentStatus) -> bool
fn eq(&self, other: &ComponentStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ComponentStatus
impl StructuralPartialEq for ComponentStatus