pub struct PowerSourceState {
pub component_id: String,
pub soc_percent: Option<Scalar>,
pub soh_percent: Option<Scalar>,
pub voltage: Option<Scalar>,
pub current: Option<Scalar>,
pub temperature: Option<Scalar>,
pub remaining_s: Option<Scalar>,
pub cycle_count: u32,
pub cell_voltages: Vec<Scalar>,
pub vendor_status_code: u32,
}Fields
component_id: Stringsoc_percent: Option<Scalar>soh_percent: Option<Scalar>voltage: Option<Scalar>current: Option<Scalar>temperature: Option<Scalar>remaining_s: Option<Scalar>cycle_count: u32cell_voltages: Vec<Scalar>vendor_status_code: u32Trait Implementations
Sourceimpl Clone for PowerSourceState
impl Clone for PowerSourceState
Sourcefn clone(&self) -> PowerSourceState
fn clone(&self) -> PowerSourceState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerSourceState
impl Debug for PowerSourceState
Sourceimpl Default for PowerSourceState
impl Default for PowerSourceState
Sourceimpl Message for PowerSourceState
impl Message for PowerSourceState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PowerSourceState
impl PartialEq for PowerSourceState
Sourcefn eq(&self, other: &PowerSourceState) -> bool
fn eq(&self, other: &PowerSourceState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PowerSourceState